compilerplugins/clang/unusedfields.writeonly.results |    2 +-
 compilerplugins/clang/unusedmethods.results          |    2 +-
 include/vcl/commandevent.hxx                         |   12 ++++++------
 sc/source/ui/app/inputwin.cxx                        |    4 ++--
 sd/source/ui/inc/slideshow.hxx                       |    4 ++--
 sd/source/ui/slideshow/slideshow.cxx                 |    2 +-
 sd/source/ui/slideshow/slideshowimpl.cxx             |    2 +-
 sd/source/ui/slideshow/slideshowimpl.hxx             |    2 +-
 sd/source/ui/view/viewshel.cxx                       |    4 ++--
 sw/source/uibase/docvw/edtwin.cxx                    |    2 +-
 vcl/inc/salwtype.hxx                                 |    4 ++--
 vcl/source/window/commandevent.cxx                   |    6 +++---
 vcl/source/window/winproc.cxx                        |   16 ++++++++--------
 vcl/unx/gtk3/gtkframe.cxx                            |    4 ++--
 14 files changed, 33 insertions(+), 33 deletions(-)

New commits:
commit 35319adcc28f197b73e146f9ba233e20616fd11f
Author:     Povilas Kanapickas <povi...@radix.lt>
AuthorDate: Fri Sep 2 00:04:41 2022 +0300
Commit:     Noel Grandin <noel.gran...@collabora.co.uk>
CommitDate: Mon Sep 5 16:21:49 2022 +0200

    vcl: Rename Swipe event to GestureSwipe
    
    We have 5 gesture types: GestureZoom, GestureRotate, GesturePan, Swipe
    and LongPress. For consistency all of these will use Gesture as a prefix
    to reduce confusion and for easier grepping throughout the codebase.
    
    Change-Id: I8b9e245d011203a19c1172f9833c172f65382caa
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/139243
    Tested-by: Jenkins
    Reviewed-by: Noel Grandin <noel.gran...@collabora.co.uk>

diff --git a/compilerplugins/clang/unusedfields.writeonly.results 
b/compilerplugins/clang/unusedfields.writeonly.results
index 33f995f77007..ccc4881de531 100644
--- a/compilerplugins/clang/unusedfields.writeonly.results
+++ b/compilerplugins/clang/unusedfields.writeonly.results
@@ -1077,7 +1077,7 @@ vcl/inc/salwtype.hxx:226
 vcl/inc/salwtype.hxx:239
     SalInputContext mpFont rtl::Reference<LogicalFontInstance>
 vcl/inc/salwtype.hxx:246
-    SalSwipeEvent mnVelocityY double
+    SalGestureSwipeEvent mnVelocityY double
 vcl/inc/scanlinewriter.hxx:35
     vcl::ScanlineWriter mpCurrentScanline sal_uInt8 *
 vcl/inc/svdata.hxx:464
diff --git a/compilerplugins/clang/unusedmethods.results 
b/compilerplugins/clang/unusedmethods.results
index 1dd04177ee82..7c0f0279d085 100644
--- a/compilerplugins/clang/unusedmethods.results
+++ b/compilerplugins/clang/unusedmethods.results
@@ -2045,7 +2045,7 @@ include/vcl/commandevent.hxx:249
 include/vcl/commandevent.hxx:256
     _Bool CommandMediaData::GetPassThroughToOS() const
 include/vcl/commandevent.hxx:276
-     CommandSwipeData::CommandSwipeData()
+     CommandGestureSwipeData::CommandGestureSwipeData()
 include/vcl/commandevent.hxx:293
      CommandLongPressData::CommandLongPressData()
 include/vcl/cursor.hxx:96
diff --git a/include/vcl/commandevent.hxx b/include/vcl/commandevent.hxx
index 9708ab818101..d8c2b702987e 100644
--- a/include/vcl/commandevent.hxx
+++ b/include/vcl/commandevent.hxx
@@ -38,7 +38,7 @@ class CommandModKeyData;
 class CommandDialogData;
 class CommandMediaData;
 class CommandSelectionChangeData;
-class CommandSwipeData;
+class CommandGestureSwipeData;
 class CommandLongPressData;
 class CommandGesturePanData;
 class CommandGestureZoomData;
@@ -91,7 +91,7 @@ public:
     const CommandDialogData*            GetDialogData() const;
           CommandMediaData*             GetMediaData() const;
     const CommandSelectionChangeData*   GetSelectionChangeData() const;
-    const CommandSwipeData*             GetSwipeData() const;
+    const CommandGestureSwipeData*      GetGestureSwipeData() const;
     const CommandLongPressData*         GetLongPressData() const;
     const CommandGesturePanData*        GetGesturePanData() const;
     const CommandGestureZoomData*       GetGestureZoomData() const;
@@ -275,15 +275,15 @@ public:
     sal_uLong          GetEnd() const { return mnEnd; }
 };
 
-class VCL_DLLPUBLIC CommandSwipeData
+class VCL_DLLPUBLIC CommandGestureSwipeData
 {
     double mnVelocityX;
 public:
-    CommandSwipeData()
+    CommandGestureSwipeData()
         : mnVelocityX(0)
     {
     }
-    CommandSwipeData(double nVelocityX)
+    CommandGestureSwipeData(double nVelocityX)
         : mnVelocityX(nVelocityX)
     {
     }
@@ -383,7 +383,7 @@ enum class CommandEventId
     SelectionChange         = 18,
     PrepareReconversion     = 19,
     QueryCharPosition       = 20,
-    Swipe                   = 21,
+    GestureSwipe            = 21,
     LongPress               = 22,
     GesturePan              = 23,
     GestureZoom             = 24,
diff --git a/sd/source/ui/inc/slideshow.hxx b/sd/source/ui/inc/slideshow.hxx
index 35b93afe8b05..2f127f4610a3 100644
--- a/sd/source/ui/inc/slideshow.hxx
+++ b/sd/source/ui/inc/slideshow.hxx
@@ -48,7 +48,7 @@ class Size;
 namespace vcl { class Window; }
 class SfxRequest;
 class WorkWindow;
-class CommandSwipeData;
+class CommandGestureSwipeData;
 class CommandLongPressData;
 struct ImplSVEvent;
 
@@ -145,7 +145,7 @@ public:
     /** sets or clears the pause state of the running slideshow.
         !!!! This should only be called by the SdShowWindow !!!!*/
     void pause( bool bPause );
-    bool swipe(const CommandSwipeData &rSwipeData);
+    bool swipe(const CommandGestureSwipeData &rSwipeData);
     bool longpress(const CommandLongPressData& rLongPressData);
 
     // settings
diff --git a/sd/source/ui/slideshow/slideshow.cxx 
b/sd/source/ui/slideshow/slideshow.cxx
index bade6d05ec44..00702d422631 100644
--- a/sd/source/ui/slideshow/slideshow.cxx
+++ b/sd/source/ui/slideshow/slideshow.cxx
@@ -1015,7 +1015,7 @@ void SlideShow::pause( bool bPause )
     }
 }
 
-bool SlideShow::swipe(const CommandSwipeData& rSwipeData)
+bool SlideShow::swipe(const CommandGestureSwipeData& rSwipeData)
 {
     return mxController.is() && mxController->swipe(rSwipeData);
 }
diff --git a/sd/source/ui/slideshow/slideshowimpl.cxx 
b/sd/source/ui/slideshow/slideshowimpl.cxx
index 9c0d31dead5d..b13ced3c128f 100644
--- a/sd/source/ui/slideshow/slideshowimpl.cxx
+++ b/sd/source/ui/slideshow/slideshowimpl.cxx
@@ -1153,7 +1153,7 @@ void SlideshowImpl::slideEnded(const bool bReverse)
         gotoNextSlide();
 }
 
-bool SlideshowImpl::swipe(const CommandSwipeData &rSwipeData)
+bool SlideshowImpl::swipe(const CommandGestureSwipeData &rSwipeData)
 {
     if (mbUsePen || mnContextMenuEvent)
         return false;
diff --git a/sd/source/ui/slideshow/slideshowimpl.hxx 
b/sd/source/ui/slideshow/slideshowimpl.hxx
index 09177762c598..b6cd778d8763 100644
--- a/sd/source/ui/slideshow/slideshowimpl.hxx
+++ b/sd/source/ui/slideshow/slideshowimpl.hxx
@@ -185,7 +185,7 @@ public:
     /// @throws css::uno::RuntimeException
     void hyperLinkClicked(const OUString & hyperLink);
     void click(const css::uno::Reference< css::drawing::XShape > & xShape);
-    bool swipe(const CommandSwipeData &rSwipeData);
+    bool swipe(const CommandGestureSwipeData &rSwipeData);
     bool longpress(const CommandLongPressData& rLongPressData);
 
     /// ends the presentation async
diff --git a/sd/source/ui/view/viewshel.cxx b/sd/source/ui/view/viewshel.cxx
index 2a249f4a795c..5df0bf11d00a 100644
--- a/sd/source/ui/view/viewshel.cxx
+++ b/sd/source/ui/view/viewshel.cxx
@@ -661,12 +661,12 @@ bool ViewShell::HandleScrollCommand(const CommandEvent& 
rCEvt, ::sd::Window* pWi
 
     switch( rCEvt.GetCommand() )
     {
-        case CommandEventId::Swipe:
+        case CommandEventId::GestureSwipe:
             {
                 rtl::Reference< SlideShow > xSlideShow( 
SlideShow::GetSlideShow( GetViewShellBase() ) );
                 if (xSlideShow.is())
                 {
-                    const CommandSwipeData* pSwipeData = rCEvt.GetSwipeData();
+                    const CommandGestureSwipeData* pSwipeData = 
rCEvt.GetGestureSwipeData();
                     bDone = xSlideShow->swipe(*pSwipeData);
                 }
             }
diff --git a/sw/source/uibase/docvw/edtwin.cxx 
b/sw/source/uibase/docvw/edtwin.cxx
index e169a5b44299..04b31378e068 100644
--- a/sw/source/uibase/docvw/edtwin.cxx
+++ b/sw/source/uibase/docvw/edtwin.cxx
@@ -5611,7 +5611,7 @@ void SwEditWin::Command( const CommandEvent& rCEvt )
             break;
 
     case CommandEventId::LongPress:
-    case CommandEventId::Swipe: //nothing yet
+    case CommandEventId::GestureSwipe: //nothing yet
             break;
 
     case CommandEventId::StartExtTextInput:
diff --git a/vcl/inc/salwtype.hxx b/vcl/inc/salwtype.hxx
index 55de89464c3f..14883f43975f 100644
--- a/vcl/inc/salwtype.hxx
+++ b/vcl/inc/salwtype.hxx
@@ -89,7 +89,7 @@ enum class SalEvent {
     SurroundingTextSelectionChange,
     StartReconversion,
     QueryCharPosition,
-    Swipe,
+    GestureSwipe,
     LongPress,
     ExternalGesture,
     GesturePan,
@@ -244,7 +244,7 @@ struct SalInputContext
     InputContextFlags      mnOptions;
 };
 
-struct SalSwipeEvent
+struct SalGestureSwipeEvent
 {
     double mnVelocityX;
     double mnVelocityY;
diff --git a/vcl/source/window/commandevent.cxx 
b/vcl/source/window/commandevent.cxx
index 53be6515a3f7..ef3f753ac6a5 100644
--- a/vcl/source/window/commandevent.cxx
+++ b/vcl/source/window/commandevent.cxx
@@ -171,10 +171,10 @@ const CommandSelectionChangeData* 
CommandEvent::GetSelectionChangeData() const
         return nullptr;
 }
 
-const CommandSwipeData* CommandEvent::GetSwipeData() const
+const CommandGestureSwipeData* CommandEvent::GetGestureSwipeData() const
 {
-    if( mnCommand == CommandEventId::Swipe )
-        return static_cast<const CommandSwipeData*>(mpData);
+    if( mnCommand == CommandEventId::GestureSwipe )
+        return static_cast<const CommandGestureSwipeData*>(mpData);
     else
         return nullptr;
 }
diff --git a/vcl/source/window/winproc.cxx b/vcl/source/window/winproc.cxx
index efa818d7b60e..e0af8255e514 100644
--- a/vcl/source/window/winproc.cxx
+++ b/vcl/source/window/winproc.cxx
@@ -1743,27 +1743,27 @@ static bool ImplHandleWheelEvent(vcl::Window* pWindow, 
const SalWheelMouseEvent&
 
 namespace {
 
-class HandleSwipeEvent : public HandleGestureEvent
+class HandleGestureSwipeEvent : public HandleGestureEvent
 {
 private:
-    CommandSwipeData m_aSwipeData;
+    CommandGestureSwipeData m_aSwipeData;
 public:
-    HandleSwipeEvent(vcl::Window *pWindow, const SalSwipeEvent& rEvt)
+    HandleGestureSwipeEvent(vcl::Window *pWindow, const SalGestureSwipeEvent& 
rEvt)
         : HandleGestureEvent(pWindow, Point(rEvt.mnX, rEvt.mnY)),
           m_aSwipeData(rEvt.mnVelocityX)
     {
     }
     virtual bool CallCommand(vcl::Window *pWindow, const Point &/*rMousePos*/) 
override
     {
-        return ImplCallCommand(pWindow, CommandEventId::Swipe, &m_aSwipeData);
+        return ImplCallCommand(pWindow, CommandEventId::GestureSwipe, 
&m_aSwipeData);
     }
 };
 
 }
 
-static bool ImplHandleSwipe(vcl::Window *pWindow, const SalSwipeEvent& rEvt)
+static bool ImplHandleSwipe(vcl::Window *pWindow, const SalGestureSwipeEvent& 
rEvt)
 {
-    HandleSwipeEvent aHandler(pWindow, rEvt);
+    HandleGestureSwipeEvent aHandler(pWindow, rEvt);
     return aHandler.HandleEvent();
 }
 
@@ -2903,8 +2903,8 @@ bool ImplWindowFrameProc( vcl::Window* _pWindow, SalEvent 
nEvent, const void* pE
             ImplHandleSalQueryCharPosition( pWindow, 
const_cast<SalQueryCharPositionEvent *>(static_cast<SalQueryCharPositionEvent 
const *>(pEvent)) );
             break;
 
-        case SalEvent::Swipe:
-            bRet = ImplHandleSwipe(pWindow, *static_cast<const 
SalSwipeEvent*>(pEvent));
+        case SalEvent::GestureSwipe:
+            bRet = ImplHandleSwipe(pWindow, *static_cast<const 
SalGestureSwipeEvent*>(pEvent));
             break;
 
         case SalEvent::LongPress:
diff --git a/vcl/unx/gtk3/gtkframe.cxx b/vcl/unx/gtk3/gtkframe.cxx
index 39ed25e1ffa8..3992672b479b 100644
--- a/vcl/unx/gtk3/gtkframe.cxx
+++ b/vcl/unx/gtk3/gtkframe.cxx
@@ -3427,14 +3427,14 @@ void GtkSalFrame::gestureSwipe(GtkGestureSwipe* 
gesture, gdouble velocity_x, gdo
     //within the same vcl window
     if (gtk_gesture_get_point(GTK_GESTURE(gesture), sequence, &x, &y))
     {
-        SalSwipeEvent aEvent;
+        SalGestureSwipeEvent aEvent;
         aEvent.mnVelocityX = velocity_x;
         aEvent.mnVelocityY = velocity_y;
         aEvent.mnX = x;
         aEvent.mnY = y;
 
         GtkSalFrame* pThis = static_cast<GtkSalFrame*>(frame);
-        pThis->CallCallbackExc(SalEvent::Swipe, &aEvent);
+        pThis->CallCallbackExc(SalEvent::GestureSwipe, &aEvent);
     }
 }
 

Reply via email to
diff --git a/sc/source/ui/app/inputwin.cxx b/sc/source/ui/app/inputwin.cxx
index 384753ad0745..55e40f0f25d2 100644
--- a/sc/source/ui/app/inputwin.cxx
+++ b/sc/source/ui/app/inputwin.cxx
@@ -1760,9 +1760,9 @@ bool ScTextWnd::Command( const CommandEvent& rCEvt )
         {
             //don't call InputChanged for CommandEventId::Wheel
         }
-        else if ( nCommand == CommandEventId::Swipe )
+        else if ( nCommand == CommandEventId::GestureSwipe )
         {
             //don't call InputChanged for CommandEventId::Swipe
         }
         else if ( nCommand == CommandEventId::LongPress )
         {
@@ -1760,9 +1760,9 @@ bool ScTextWnd::Command( const CommandEvent& rCEvt )
         {
-            //don't call InputChanged for CommandEventId::Swipe
+            //don't call InputChanged for CommandEventId::GestureSwipe
         }
         else if ( nCommand == CommandEventId::LongPress )